File

Struct File 

pub struct File { /* private fields */ }
An open HDF5 file for reading.

When the mmap feature is enabled (the default), File::open uses memory-mapped I/O so the OS page-cache serves reads with zero copies. Use File::open_buffered to get the old read-into-Vec<u8> behaviour, or File::from_bytes for fully in-memory operation.

Implementations

Source

impl File

pub fn open<P: AsRef<Path>>(path: P) -> Result<Self, Error>

Open an HDF5 file from a filesystem path.

When the mmap feature is enabled (default), this uses memory-mapped I/O. Otherwise it reads the entire file into a Vec<u8>.

pub fn open_buffered<P: AsRef<Path>>(path: P) -> Result<Self, Error>

Open an HDF5 file by reading it entirely into memory.

This is the pre-mmap behaviour and is useful when memory-mapping is undesirable (e.g. network filesystems, very small files, etc.).

pub fn from_bytes(data: Vec<u8>) -> Result<Self, Error>

Open an HDF5 file from an in-memory byte vector.

pub fn root(&self) -> Group<'_>

Returns a handle to the root group.

pub fn dataset(&self, path: &str) -> Result<Dataset<'_>, Error>

Resolve a path and return a Dataset handle.

The path uses / separators (e.g., "group1/values").

pub fn group(&self, path: &str) -> Result<Group<'_>, Error>

Resolve a path and return a Group handle.

The path uses / separators (e.g., "sensors"). Use "/" or "" for the root group.

pub fn as_bytes(&self) -> &[u8]

Returns the raw file bytes.

pub fn superblock(&self) -> &Superblock

Returns a reference to the parsed superblock.

pub fn is_mmap(&self) -> bool

Returns true when the file is backed by memory-mapped I/O.